Module error_handler

Module error_handler 

Error handling and recovery for operations.

Provides error classification, user action selection, and dangerous operation confirmation. In a TUI/CLI context the actual prompting is handled by the caller — this module provides the types and logic.

Ported from opendev/core/runtime/monitoring/error_handler.py.

Structs

ErrorResult
Result of error handling.
OperationError
Information about an operation error for display/handling.

Enums

ErrorAction
Actions user can take on error.

Functions

available_actions
Build the list of available options for an operation error.
is_transient_error
Classify whether an error is likely transient and worth retrying.
resolve_choice
Resolve a user’s choice character into an ErrorResult.