pub fn available_actions(
error: &OperationError,
) -> Vec<(ErrorAction, &'static str)>Expand description
Build the list of available options for an operation error.
pub fn available_actions(
error: &OperationError,
) -> Vec<(ErrorAction, &'static str)>Build the list of available options for an operation error.