pub fn resolve_choice(
choice: char,
error: &OperationError,
) -> Option<ErrorResult>Expand description
Resolve a user’s choice character into an ErrorResult.
Returns None if the choice is invalid or not allowed by the error options.
pub fn resolve_choice(
choice: char,
error: &OperationError,
) -> Option<ErrorResult>Resolve a user’s choice character into an ErrorResult.
Returns None if the choice is invalid or not allowed by the error options.