pub type PlanApprovalReceiver = UnboundedReceiver<PlanApprovalRequest>;Expand description
Convenience type alias for the receiver half that the TUI polls.
Aliased Type
pub struct PlanApprovalReceiver { /* private fields */ }pub type PlanApprovalReceiver = UnboundedReceiver<PlanApprovalRequest>;Convenience type alias for the receiver half that the TUI polls.
pub struct PlanApprovalReceiver { /* private fields */ }