pub struct SecretMatch {
pub kind: SecretKind,
pub start: usize,
pub end: usize,
pub matched_text: String,
}Expand description
A single detected secret with its location in the input text.
Fields
kind: SecretKindWhat kind of secret was detected.
start: usizeByte offset of the start of the match.
end: usizeByte offset of the end of the match (exclusive).
matched_text: StringThe matched text.