Module state_snapshot

Module state_snapshot 

Application state snapshot for crash recovery (#97).

Periodically serializes essential session state to a temp file so that incomplete sessions can be detected and recovered on the next startup.

Structs

AppStateSnapshot
Essential application state that is persisted for crash recovery.
SnapshotPersistence
Manages reading and writing AppStateSnapshot to disk.
ToolResultEntry
A single tool result entry stored in the snapshot.