Sandbox mode for restricting tool operations.
When enabled, only whitelisted commands may be executed by the bash tool, and file write/edit operations are restricted to paths within the project directory.
Structs
- Sandbox
Config - Configuration for sandbox mode.