Application state snapshot for crash recovery (#97).
Periodically serializes essential session state to a temp file so that incomplete sessions can be detected and recovered on the next startup.
Structs
- AppState
Snapshot - Essential application state that is persisted for crash recovery.
- Snapshot
Persistence - Manages reading and writing
AppStateSnapshotto disk. - Tool
Result Entry - A single tool result entry stored in the snapshot.